package org.jlmonteagudo.encuestas

class EncuestaController {

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

	def index = {
		redirect(action: "showEncuesta", params: params)
	}
	

	def showEncuesta = {
		def encuestaInstance = searchEncuesta(params.id)
		def chartColumns
		def chartData = []
		
		if (encuestaInstance) {
			chartColumns = [['string', ''], ['number', '']]
			encuestaInstance.opciones.each {
				chartData << [it.titulo, it.numeroVotaciones]
			}
		}
		
		return [encuestaInstance : encuestaInstance, chartColumns : chartColumns, chartData : chartData]
	}

		
	Encuesta searchEncuesta(def encuestaId) {
		if (encuestaId) return Encuesta.get(encuestaId)
		def encuestas = Encuesta.listOrderById(max : 1, order : "desc")
		if (encuestas) return encuestas[0]
	}
	

	def createEncuestaFlow = {
		
		newEncuesta {
			on("addOption") {
				flow.encuestaInstance = new Encuesta(params)
				!flow.encuestaInstance.validate() ? error() : success()
			}.to "addOption"
			on("cancel").to "cancel"
		}
		
		cancel {
			redirect(action : "index")
		}
		
		addOption {
			on("addOption") {
				
				flow.opcionInstance = new Opcion(params)
				if (!flow.opcionInstance.validate()) {
					error()
				}
				else {
					flow.encuestaInstance.addToOpciones(flow.opcionInstance)
					flow.opcionInstance = new Opcion()
					success()
				}
				
			}.to "addOption"
			on("saveEncuesta"){
				!flow.encuestaInstance.save() ? error() : success()
			}.to "saveEncuesta"
			on("cancel").to "cancel"
		}
		
		saveEncuesta {
			redirect(action: "showEncuesta")
		}

	}	


	def saveVoto = {
		
		def opcion = Opcion.get(params.opcionId)
		def encuesta
		
		if (!opcion) {
			flash.message = message(code: "encuestas.opcion.not.selected.message")
			redirect(action: "showEncuesta", id:params.id)
		}
		
		encuesta = opcion.encuesta
		encuesta.numeroTotalVotaciones++
		opcion.numeroVotaciones++
		
		if (encuesta.save()) {
			flash.message = message(code: "encuestas.opcion.vote.message")
		}
		else {
			flash.message = message(code: "encuestas.opcion.vote.error")
		}
		
		redirect(action: "showEncuesta", id:encuesta.id)
		
	}
		

	def delete = {
		def encuestaInstance = Encuesta.get(params.id)
		if (encuestaInstance) {
			try {
				encuestaInstance.delete(flush: true)
				flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'encuesta.label', default: 'Encuesta'), params.id])}"
				redirect(action: "showEncuesta")
			}
			catch (org.springframework.dao.DataIntegrityViolationException e) {
				flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'encuesta.label', default: 'Encuesta'), params.id])}"
				redirect(action: "showEncuesta", id: params.id)
			}
		}
		else {
			flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'encuesta.label', default: 'Encuesta'), params.id])}"
			redirect(action: "showEncuesta")
		}
	}

}
